@@ -146,7 +146,7 @@ ps3000a.PS3000A_TRIGGER_STATE = make_enum([
     
 ps3000a.PS3000A_THRESHOLD_DIRECTION = make_enum([
     ("PS3000A_ABOVE", "PS3000A_INSIDE"),
-    ("PS3000A_BELOW", "PS3000A_OUTSIDE"),
+    ("PS3000A_BELOW", "PS3000A_OUTSIDE","PS3000A_NONE"),
     ("PS3000A_RISING", "PS3000A_ENTER"),
     ("PS3000A_FALLING", "PS3000A_EXIT"),
     ("PS3000A_RISING_OR_FALLING", "PS3000A_ENTER_OR_EXIT"),
@@ -155,8 +155,7 @@ ps3000a.PS3000A_THRESHOLD_DIRECTION = make_enum([
     "PS3000A_RISING_LOWER",
     "PS3000A_FALLING_LOWER"
     "PS3000A_POSITIVE_RUNT",
-    "PS3000A_NEGATIVE_RUNT",
-    "PS3000A_NONE"
+    "PS3000A_NEGATIVE_RUNT"
     ])
     
 ps3000a.PS3000A_THRESHOLD_MODE = make_enum([
