@@ -182,6 +182,19 @@ ps5000a.PS5000A_TIME_UNITS = make_enum([
 ps5000a.PICO_RATIO_MODE = {k[19:]: v for k, v in ps5000a.PS5000A_RATIO_MODE.items()}
 
 
+
+class PS5000A_TRIGGER_INFO(Structure):
+    _pack_ = 1
+    _fields_ = [("status", c_uint32),
+                ("segmentIndex", c_uint32),
+                ("triggerIndex", c_uint32),
+                ("triggerTime", c_int64),
+                ("timeUnits", c_int16),
+                ("reserved0", c_int16),
+                ("timeStampCounter", c_uint64)]
+
+ps5000a.PS5000A_TRIGGER_INFO = PS5000A_TRIGGER_INFO
+
 class PS5000A_DIGITAL_CHANNEL_DIRECTIONS(Structure):
     _pack_ = 1
     _fields_ = [("channel", c_int32),
@@ -215,8 +228,17 @@ class PS5000A_CONDITION (Structure):
 				("condition", c_int16)]
                 
 ps5000a.PS5000A_CONDITION = PS5000A_CONDITION
-				
 
+class PS5000A_PWQ_CONDITIONS (Structure):
+    _pack_ = 1
+    _fields_ = [("channelA", c_int16),
+                ("channelB", c_int16),
+                ("channelC", c_int16),
+                ("channelD", c_int16),
+                ("external", c_int16),
+                ("aux", c_int16)]
+
+ps5000a.PS5000A_PWQ_CONDITIONS = PS5000A_PWQ_CONDITIONS
 
 doc = """ PICO_STATUS (ps5000aOpenUnit)
     (
@@ -467,6 +489,14 @@ doc = """ PICO_STATUS ps5000aSetTriggerChannelPropertiesV2
     ); """
 ps5000a.make_symbol("_SetTriggerChannelPropertiesV2", "ps5000aSetTriggerChannelPropertiesV2", c_uint32,
                     [c_int16, c_void_p, c_int16, c_int16], doc)
+                    
+doc = """ PICO_STATUS ps5000aSetAutoTriggerMicroSeconds
+    (
+        int16_t                             handle,
+        uint64_t                          autoTriggerMicroseconds,
+    ); """
+ps5000a.make_symbol("_SetAutoTriggerMicroSeconds", "ps5000aSetAutoTriggerMicroSeconds", c_uint32,
+                    [c_int16, c_uint64], doc)
 
 doc = """ PICO_STATUS ps5000aSetTriggerChannelConditions
     (
@@ -676,20 +706,20 @@ ps5000a.StreamingReadyType = C_CALLBACK_FUNCTION_FACTORY(None,
 
 ps5000a.StreamingReadyType.__doc__ = doc
 
-# TODO sort out how to make a callback for a C function in ctypes!
-# doc = """ void *ps5000aStreamingReady
-#     (
-#         int16_t   handle,
-#         int32_t   noOfSamples,
-#         uint32_t  startIndex,
-#         int16_t   overflow,
-#         uint32_t  triggerAt,
-#         int16_t   triggered,
-#         int16_t   autoStop,
-#         void     *pParameter
-#     ); """
-# ps5000a.make_symbol("_StreamingReady", "ps5000aStreamingReady", c_void_p,
-#                     [c_int16, c_int32, c_uint32, c_int16, c_uint32, c_int16, c_int16, c_void_p], doc)
+doc = """void *ps5000aBlockReady
+    (
+        int16_t    handle,
+        PICO_STATUS    status,
+        void    *pParameter
+    );
+    """
+    
+ps5000a.BlockReadyType = C_CALLBACK_FUNCTION_FACTORY(None,
+                                                     c_int16,
+                                                     c_int32,
+                                                     c_void_p)
+                                                     
+ps5000a.BlockReadyType.__doc__ = doc
 
 doc = """ PICO_STATUS ps5000aNoOfStreamingValues
     (
@@ -931,4 +961,43 @@ doc = """ PICO_STATUS ps5000aSetTriggerDigitalPortProperties
         int16_t                             nDirections
     ); """
 ps5000a.make_symbol("_SetTriggerDigitalPortProperties", "ps5000aSetTriggerDigitalPortProperties", c_uint32,
-                    [c_int16, c_void_p, c_int16], doc)
\ No newline at end of file
+                    [c_int16, c_void_p, c_int16], doc)
+
+doc = """ PICO_STATUS ps5000aSetPulseWidthQualifierProperties
+    (
+        int16_t                            handle,
+        uint32_t                           lower,
+        uint32_t                           upper,
+        PS5000A_PULSE_WIDTH_TYPE           type
+    ); """
+ps5000a.make_symbol("_SetPulseWidthQualifierProperties", "ps5000aSetPulseWidthQualifierProperties", c_uint32, 
+                    [c_int16, c_uint32, c_uint32, c_int32], doc)
+
+doc = """ PICO_STATUS ps5000aSetPulseWidthQualifierConditions
+    (
+        int16_t                            handle,
+        PS5000A_CONDITION                  *conditions,
+        int16_t                            nConditions,
+        PS5000A_CONDITIONS_INFO            info
+    ); """
+ps5000a.make_symbol("_SetPulseWidthQualifierConditions", "ps5000aSetPulseWidthQualifierConditions", c_uint32,
+                    [c_int16, c_void_p, c_int16, c_int32], doc)
+                    
+doc = """ PICO_STATUS ps5000aSetPulseWidthQualifierDirections
+    (
+        int16_t                             handle,
+        PS5000A_DIRECTION                   *directions,
+        int16_t                             nDirections
+    ); """
+ps5000a.make_symbol("_SetPulseWidthQualifierDirections", "ps5000aSetPulseWidthQualifierDirections", c_uint32,
+                    [c_int16, c_void_p, c_int16], doc)
+
+doc = """ PICO_STATUS ps5000aGetMinimumTimebaseStateless
+    (
+        int16_t                      handle,
+        PS5000A_CHANNEL_FLAGS        enabledChannelOrPortFlags,
+        uint32_t                     *timebase,
+        double                       *timeInterval,
+        PS5000A_DEVICE_RESOLUTION    resolution
+    ); """
+ps5000a.make_symbol("_GetMinimumTimebaseStateless", "ps5000aGetMinimumTimebaseStateless", c_uint32, [c_int16, c_uint32, c_void_p, c_void_p, c_uint32], doc)    
\ No newline at end of file
